/*******************************************************************************
 * Copyright (c) 2010, 2020 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     Lars Vogel <Lars.Vogel@gmail.com> - Bug 420836
 *******************************************************************************/

/* ColorDefinitions for the light theme for the Eclipse IDE
*
* ThemeExtensions and ColorDefinition are  mapped to the Colors and Fonts preference
* dialog in the IDE
*/

/* New ColorDefinitions for the E4 default theme */ 
ThemesExtension { color-definition: 
	'#org-eclipse-ui-workbench-INACTIVE_UNSELECTED_TABS_COLOR_START', 
	'#org-eclipse-ui-workbench-INACTIVE_UNSELECTED_TABS_COLOR_END',
	'#org-eclipse-ui-workbench-INACTIVE_TAB_OUTER_KEYLINE_COLOR',
	'#org-eclipse-ui-workbench-INACTIVE_TAB_INNER_KEYLINE_COLOR',
	'#org-eclipse-ui-workbench-INACTIVE_TAB_OUTLINE_COLOR',
	'#org-eclipse-ui-workbench-ACTIVE_UNSELECTED_TABS_COLOR_START',
	'#org-eclipse-ui-workbench-ACTIVE_UNSELECTED_TABS_COLOR_END',
	'#org-eclipse-ui-workbench-ACTIVE_TAB_OUTER_KEYLINE_COLOR',
	'#org-eclipse-ui-workbench-ACTIVE_TAB_INNER_KEYLINE_COLOR',
	'#org-eclipse-ui-workbench-ACTIVE_TAB_OUTLINE_COLOR',
	'#org-eclipse-ui-workbench-ACTIVE_TAB_TEXT_COLOR',
	'#org-eclipse-ui-workbench-INACTIVE_TAB_TEXT_COLOR',
	'#org-eclipse-ui-workbench-SECONDARY_BACKGROUND';
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_UNSELECTED_TABS_COLOR_START {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_UNSELECTED_TABS_COLOR_START')
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_UNSELECTED_TABS_COLOR_END {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_UNSELECTED_TABS_COLOR_END');
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_OUTER_KEYLINE_COLOR {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_TAB_OUTER_KEYLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_INNER_KEYLINE_COLOR {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_TAB_INNER_KEYLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_OUTLINE_COLOR {
	color: #b6bccc;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_TAB_OUTLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_UNSELECTED_TABS_COLOR_START {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_UNSELECTED_TABS_COLOR_START');
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_UNSELECTED_TABS_COLOR_END {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_UNSELECTED_TABS_COLOR_END');
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_OUTER_KEYLINE_COLOR {
	color: #cccccc;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_TAB_OUTER_KEYLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_INNER_KEYLINE_COLOR {
	color: #ffffff;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_TAB_INNER_KEYLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_OUTLINE_COLOR {
	color: #b6bccc;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_TAB_OUTLINE_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-SECONDARY_BACKGROUND {
	color: #f8f8f8;
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=SECONDARY_BACKGROUND');
	editable: false;
}

/* Already existing ColorDefinitions overridden for the E4 default theme */
ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_BG_START {
	color: #dddfe5;
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_BG_END {
	color: #ffffff;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_BG_START{
	color: #ffffff;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_BG_END {
	color: #ffffff;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_BG_START {
	color: #FFFFFF;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_BG_END {
	color: #FFFFFF;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_TEXT_COLOR {
	/* Never use black */
	color: #101010;
}

ColorDefinition#org-eclipse-ui-workbench-ACTIVE_TAB_TEXT_COLOR {
	color: '#COLOR_WIDGET_FOREGROUND';
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=ACTIVE_TAB_TEXT_COLOR');
}

ColorDefinition#org-eclipse-ui-workbench-INACTIVE_TAB_TEXT_COLOR {
	color: '#COLOR_WIDGET_FOREGROUND';
	category: '#org-eclipse-ui-presentation-default';
	label: url('platform:/plugin/org.eclipse.ui.themes?message=INACTIVE_TAB_TEXT_COLOR');
}
