/*******************************************************************************
 * Copyright (c) 2010, 2015 Andrea Guarinoni and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Andrea Guarinoni <andrea.guarinoni.dev@outlook.com> - initial API and implementation
 *     Lars Vogel <Lars.Vogel@vogella.com> - initial API and implementation
 *     Stefan Winkler <stefan@winklerweb.net> - Bug 431845
 *     Fabio Zadrozny <fabiofz@gmail.com> - Bug 434201, 434309, 430278
 *******************************************************************************/

@import url("platform:/plugin/org.eclipse.ui.themes/css/common/e4_globalstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/dark/e4-dark_ide_colorextensions.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/dark/e4-dark_globalstyle.css"); /* Remove this to have ONLY the main IDE shell dark */
@import url("platform:/plugin/org.eclipse.ui.themes/css/dark/e4-dark_partstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/dark/e4-dark_tabstyle.css");
@import url("platform:/plugin/org.eclipse.ui.themes/css/dark/e4-dark-drag-styling.css");

CTabFolder Canvas {
	background-color: #2F2F2F;
	color: #CCC;
}

CTabFolder Scale {
	background-color: inherit;
}

.MPartStack.active CTabFolder Canvas {
	background-color: #262626;
	color: #CCC;
}

.MPartStack.active Table {
	background-color: #2F2F2F;
	color: #CCC;
}

Tree, Table {
	swt-lines-visible: false;
}

/* ##################### Bottom Status Bar ####################### */

StatusLine,
ImageBasedFrame,
#org-eclipse-ui-StatusLine,
#org-eclipse-ui-StatusLine CLabel,
#org-eclipse-ui-ProgressBar,
#org-eclipse-ui-ProgressBar Canvas {
	color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}



/* ####################### CSS for .MParts ####################### */

.MPart Form Section,
.MPart Form Label,
.MPart Form FormText,
.MPartStack .MPart Form MasterDetailsBlock-MDSashForm,
.MPartStack .MPart Form SashForm,
.MPartStack .MPart Form Sash,
.MPart Form Button[style~='SWT.CHECK'],
.MPart Form Button[style~='SWT.RADIO'],
.MPartStack.active .MPart Form Section,
.MPartStack.active .MPart Form Label,
.MPartStack.active .MPart Form FormText,
.MPartStack.active .MPart Form MasterDetailsBlock-MDSashForm,
.MPartStack.active .MPart Form SashForm,
.MPartStack.active .MPart Form Sash,
.MPartStack.active .MPart Form Button[style~='SWT.CHECK'],
.MPartStack.active .MPart Form Button[style~='SWT.RADIO']
{
	background-color: inherit;
	color: #f4f7f7;
}

/* Make the content of the Form brighter because the color of
   the font of some widgets is hard-coded to be black on Window */

.MPart Form,
.MPart Form Link,
.MPart Form Button,
.MPart Form Group,
.MPart Form ScrolledPageBook,
.MPart Form DependenciesComposite,
.MPart Form ListEditorComposite,
.MPart Form Text[style~='SWT.READ_ONLY'],
.MPart Form DependenciesComposite > SashForm > Section > *, /* Section > DependenciesComposite$... */
.MPartStack.active .MPart Form,
.MPartStack.active .MPart Form Link,
.MPartStack.active .MPart Form Button,
.MPartStack.active .MPart Form Group,
.MPartStack.active .MPart Form ScrolledPageBook,
.MPartStack.active .MPart Form DependenciesComposite,
.MPartStack.active .MPart Form ListEditorComposite,
.MPartStack.active .MPart Form Text[style~='SWT.READ_ONLY'],
.MPartStack.active .MPart Form DependenciesComposite > SashForm > Section > * { /* Section > DependenciesComposite$... */
	background-color: #2F2F2F;
	color: #f4f7f7;
}
#org-eclipse-help-ui-HelpView Form,
#org-eclipse-help-ui-HelpView Form Sash,
#org-eclipse-help-ui-HelpView Form Label,
#org-eclipse-help-ui-HelpView Form Section,
#org-eclipse-help-ui-HelpView Form FormText,
#org-eclipse-help-ui-HelpView Form Button,
#org-eclipse-help-ui-HelpView Form Group,
#org-eclipse-help-ui-HelpView Form ScrolledPageBook,
#org-eclipse-help-ui-HelpView Form Text[style~='SWT.READ_ONLY'] {
	background-color: #2F2F2F;
	color: #CCCCCC;
}
.MPartStack.active #org-eclipse-help-ui-HelpView Form,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Sash,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Label,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Section,
.MPartStack.active #org-eclipse-help-ui-HelpView Form FormText,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Button,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Group,
.MPartStack.active #org-eclipse-help-ui-HelpView Form ScrolledPageBook,
.MPartStack.active #org-eclipse-help-ui-HelpView Form Text[style~='SWT.READ_ONLY'] {
	background-color: #262626;
	color: #BBBBBB;
}
.MPart Form Section Tree,
.MPartStack.active .MPart Form Section Tree {
	background-color: #313538;
	color: #DDDDDD;
}

/* Inactive view tabs  */
.MPartStack{
	swt-selected-tab-highlight: #a6a6a6;
    swt-selected-highlight-top: false;
    swt-draw-custom-tab-content-background: true;
	swt-unselected-hot-tab-color-background: #161616;
}

.MPartStack.active {
    swt-selected-tab-highlight: #2b79d7;
    swt-selected-highlight-top: false;
}

.MPartStack CTabFolder[style~='SWT.DOWN'][style~='SWT.BOTTOM'] {
    /* Set the styles for the bottom inner tabs (Bug 430051): */
    swt-tab-renderer: url('bundleclass://org.eclipse.e4.ui.workbench.renderers.swt/org.eclipse.e4.ui.workbench.renderers.swt.CTabRendering');
    swt-unselected-hot-tab-color-background: #161616;/*  Bug 465711 */
    swt-selected-tab-highlight: #a6a6a6;
    swt-selected-highlight-top: true;
}
.MPartStack.active CTabFolder[style~='SWT.DOWN'][style~='SWT.BOTTOM'] {
    /* Set the styles for the bottom inner tabs (Bug 430051): */
    swt-tab-renderer: url('bundleclass://org.eclipse.e4.ui.workbench.renderers.swt/org.eclipse.e4.ui.workbench.renderers.swt.CTabRendering');
    swt-unselected-hot-tab-color-background: #161616;/*  Bug 465711 */
    swt-selected-tab-highlight: #2b97d7;
    swt-selected-highlight-top: true;
}

/*text color of selected tab in editor */
#org-eclipse-ui-editorss CTabItem:selected{
	color: '#FFFFFF';
}

#org-eclipse-ui-editorss CTabFolder{
 	swt-selected-tab-fill : '#1E1F22';
    swt-selected-highlight-top: true;
    swt-draw-custom-tab-content-background: true;
	swt-unselected-hot-tab-color-background:#161616;
}

#org-eclipse-ui-editorss CTabFolder.active {
    swt-selected-tab-highlight: '#2b79d7';
    swt-selected-highlight-top: true;
} 

#org-eclipse-e4-ui-compatibility-editor Canvas,
#org-eclipse-e4-ui-compatibility-editor Canvas > *
{
	background-color: #1E1F22;
}
