/*******************************************************************************
 * Copyright (c) 2010, 2015 Andrea Guarinoni and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Andrea Guarinoni <andrea.guarinoni.dev@outlook.com> - initial API and implementation
 *     Stefan Winkler <stefan@winklerweb.net> - Bug 434189, 430848
 *     Simon Scholz <simon.scholz@vogella.com> - Bug 431635
 *     Fabio Zadrozny <fabiofz@gmail.com> - Bug 465148, 465711
 *     Lars Vogel <Lars.Vogel@vogella.com> Bug 463652,466275
 *******************************************************************************/

/*******************************************************************************
 * The following bugs are referred to in this style sheet
 * 2.) Bug 419377 - Setting a property to 'inherit' is not supported
 * 3.) Bug 430051 - Regression for CTabRendering when drawing bottom tabs
 *******************************************************************************/


/* ############################## Global Styles ############################## */

Shell,
Composite, ScrolledComposite, ExpandableComposite, Canvas, TabFolder, CLabel, Label,
CoolBar, Sash, Group, RefactoringLocationControl, ChangeParametersControl, Link, FilteredTree,
ProxyEntriesComposite, NonProxyHostsComposite, DelayedFilterCheckboxTree,
Splitter, ScrolledPageContent, ViewForm, LaunchConfigurationFilteredTree,
ContainerSelectionGroup, BrowseCatalogItem, EncodingSettings,
ProgressMonitorPart, DocCommentOwnerComposite, NewServerComposite,
NewManualServerComposite, ServerTypeComposite, FigureCanvas,
DependenciesComposite, ListEditorComposite, WrappedPageBook,
CompareStructureViewerSwitchingPane, CompareContentViewerSwitchingPane,
QualifiedNameComponent, RefactoringStatusViewer,
MessageLine,
Button /* SWT-BUG: checkbox inner label font color is not accessible */,
Composite > *,
Composite > * > *,
Group > StyledText {
    background-color:'#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

/* Disabled buttons should appear dimmed to distinguish them from enabled buttons */
Button.disabled {
    color: #777777;
}

/* ############################## Toolbar ############################## */
/* Ensure that the labels in the tabfolder gets updated
   See Bug 552780
*/
TabFolder > *,
CTabFolder > *,
TabFolder > Composite > *, /* Composite > CommitSearchPage$... */
CTabFolder > Composite > *, /* Composite > CommitSearchPage$... */
TabFolder > Composite > * > * { /* [style~='SWT.NO_BACKGROUND'] <- generate E4 non-sense bugs in apparently not related other rules Composite > ContentMergeViewer$... > TextMergeViewer$... */ 
	color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

/* Toolbar should inherit the colors of its container to avoid drawing artifacts*/
ToolBar {
	background-color:inherit;	
}

Combo,
List,
Text,
Spinner,
CCombo {
    background-color:'#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}
Composite > StyledText,
Shell [style~='SWT.DROP_DOWN'] > StyledText, /* for eg. folded code popup (but it's ignored) */
SashForm > StyledText {
	/*	Fix StyledText inside a SashForm */
    background-color:'#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

Text[style~='SWT.SEARCH'],
Text[style~='SWT.SEARCH'] + Label /* SWT-BUG: adjacent sibling selector is ignored (CSS2.1) */ {
    /* search boxes */
    background-color: #333;
    color: #F4F7F7;
}

Text[style~='SWT.READ_ONLY'] {
    background-color: '#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color: #bbbbbb;
}

Shell Tree, Shell Table, Shell List {
	background-color: #2F2F2F;
}

DatePicker,
DatePicker > Text,
ScheduleDatePicker,
ScheduleDatePicker > Text {
    background-color:'#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}


ScrolledFormText,
FormText {
    background-color:'#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

Table,
Tree,
RegistryFilteredTree {
    background-color:inherit;
    color:'#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

Hyperlink,
ImageHyperlink {
	background-color: inherit;
    color: #6fc5ee;
}


ViewerPane,
DrillDownComposite {
    background-color: #232323;
    color: #CCC;
}

ProgressInfoItem,
ProgressInfoItem > *,
CompareViewerPane,
CompareViewerPane > * {
    background-color: inherit;
    color: '#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

ProgressIndicator {
    background-color: #777;
    color: '#org-eclipse-ui-workbench-DARK_FOREGROUND'; 
}

DiscoveryItem,
DiscoveryItem Label,
DiscoveryItem Composite {
    background-color: #383C3E;
    color: #dddddd;
}
DiscoveryItem StyledText {
    background-color: #383C3E;
    color: #aaaaaa;
}
DiscoveryItem Link {
    background-color: #383C3E;
    color: #8B9498;
}

CatalogSwitcher,
CatalogSwitcher > ScrolledComposite > Composite > Composite /* ignored because hard-coded */,
CategoryItem {
    background-color: '#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color: #dddddd;
}
GradientCanvas,
GradientCanvas > Label {
    background-color: #3f4447;
    color: #9ac9d8;
}
GradientCanvas {
    /* SWT-BUG workaround: GradientCanvas background-color is ignored */
    background: #3f4447;
}
CategoryItem > GradientCanvas,
CategoryItem > GradientCanvas > Label {
    /* SWT-BUG workaround: a style for background is not applied on GradientCanvas (CSS engine repaint issue) */
    background-color: #fafafa;
    color: #333;
}
CategoryItem > GradientCanvas {
    /* SWT-BUG workaround: a style for background is not applied on GradientCanvas (CSS engine repaint issue) */
    background: #fafafa;
    background-image: #333;
}

WebSite {
    background-color: #41464A;
    color: #dddddd;
}

Form {
    background-color: #2F2F2F;
    color: #9AC9D8;

	/* Bug 465148: Additional styling for the Form */
    text-background-color: #2F2F2F;

	tb-toggle-hover-color: #313538;
	tb-toggle-color: #313538;
	h-hover-full-color: #313538;
	h-hover-light-color: #313538;
	h-bottom-keyline-2-color: #313538;
	h-bottom-keyline-1-color: #313538;
}

FormHeading {
    background-color: #2F2F2F;
    color: #f4f7f7;
}

Section {
    background-color: #4F5355;
    color: #AEBED0;
    background-color-titlebar: #4F5355;
    background-color-gradient-titlebar: #4F5355;
    border-color-titlebar: #4F5355;
    swt-titlebar-color: #cccccc;
	tb-toggle-hover-color: #F4F7F7;
	tb-toggle-color: #F4F7F7;
}

Table,
Tree {
	swt-header-color: #CCC;
	swt-header-background-color: #383D3F;
}

Twistie {
    color: #E8E4DF;
}

.MPartSashContainer {
    background-color: '#org-eclipse-ui-workbench-DARK_BACKGROUND'; 
    color: #EEEEEE;
}

HeapStatus {
	background-color: #4F5355;
	color: #EEEEEE;
}

PageSiteComposite, PageSiteComposite > CImageLabel {
    color: #EEEEEE;
}
PageSiteComposite > PropertyTable {
    background-color: #333;
    color: #EEEEEE;
}
PageSiteComposite > PropertyTable:disabled {
/* SWT-BUG: event is triggered but styles for PropertyTable are hard-coded */
    background-color: #444;
    color: #EEEEEE;
}

/* See Bug 430848: We need to override the theme of the Eclipse splash screen, because
 * otherwise the splash screen would be partly switched to the dark theme during startup,
 * which does not look very nice.
 */
Label#org-eclipse-ui-splash-progressText {
	background-color: inherit; /* transparent */
	color: #9c9696; /* see property startupForegroundColor in the product */
}

Label#org-eclipse-ui-buildid-text {
	background-color: inherit; /* transparent */
}

ProgressIndicator#org-eclipse-ui-splash-progressIndicator {
	background-color: #e1e1e1;
}

Link {
	swt-link-foreground-color: '#org-eclipse-ui-workbench-LINK_COLOR'
}

ExpandableComposite {
    swt-titlebar-color: #cccccc;
	tb-toggle-hover-color: #F4F7F7;
	tb-toggle-color: #F4F7F7;
}

TabbedPropertyTitle > CLabel{
	color: #9AC9D8;
}

TabbedPropertyTitle {
	swt-backgroundGradientStart-color:  #505F70;
	swt-backgroundGradientEnd-color:    #505F70;
	swt-backgroundBottomKeyline1-color: #505F70;
	swt-backgroundBottomKeyline2-color: #505F70;
}

TabbedPropertyList {
	swt-tabNormalShadow-color   : '#org-eclipse-ui-workbench-INACTIVE_TAB_OUTLINE_COLOR';             /* color of shadow lines around the tabs */
	swt-tabDarkShadow-color     : '#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_SELECTED_TEXT_COLOR'; /* line color of the tiny scroll triangle (at top / at bottom) */
	swt-tabAreaBackground-color : '#org-eclipse-ui-workbench-DARK_BACKGROUND';    /*same as canvas*/
	swt-tabBackground-color     : '#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_BG_START';
	color                       : '#org-eclipse-ui-workbench-ACTIVE_NOFOCUS_TAB_SELECTED_TEXT_COLOR'; /* text color in the tab / tab area */
}
